package jogamp.graph.curve.opengl.shader;

public class UniformNames {
    public static final String gcu_PMVMatrix01 = "gcu_PMVMatrix01"; // gcu_PMVMatrix[3]; // P, Mv, and Mvi
    public static final String gcu_ColorStatic = "gcu_ColorStatic";
    public static final String gcu_Weight = "gcu_Weight";
    public static final String gcu_ColorTexUnit = "gcu_ColorTexUnit";
    public static final String gcu_ColorTexBBox = "gcu_ColorTexBBox";
    public static final String gcu_ColorTexClearCol = "gcu_ColorTexClearCol";
    public static final String gcu_ClipFrustum = "gcu_ClipFrustum";

    public static final String gcu_PMVMatrix02 = "gcu_PMVMatrix02"; // gcu_PMVMatrix[3]; // P, Mv, and Mvi
    public static final String gcu_FboTexUnit = "gcu_FboTexUnit";
    public static final String gcu_FboTexSize = "gcu_FboTexSize";
}
